@@ -93,6 +93,14 @@ func CheckOrCreateConfigDir() error {
 		return err
 	}
 	err = createConfigDir(SCRAPERDIR)
+	if err != nil {
+		return err
+	}
+	err = createConfigDir(AUTOCALIBDIR)
+	if err != nil {
+		return err
+	}
+	err = setupDefaultAutocalibrationStrategies()
 	return err
 }
 
@@ -116,3 +124,14 @@ func StrInSlice(key string, slice []string) bool {
 	}
 	return false
 }
+
+func mergeMaps(m1 map[string][]string, m2 map[string][]string) map[string][]string {
+	merged := make(map[string][]string)
+	for k, v := range m1 {
+		merged[k] = v
+	}
+	for key, value := range m2 {
+		merged[key] = value
+	}
+	return merged
+}
\ No newline at end of file
