@@ -4,13 +4,13 @@ import (
 	"strings"
 	"testing"
 
-	"github.com/ffuf/ffuf/pkg/ffuf"
+	"github.com/ffuf/ffuf/v2/pkg/ffuf"
 )
 
 func TestNewSizeFilter(t *testing.T) {
 	f, _ := NewSizeFilter("1,2,3,444,5-90")
 	sizeRepr := f.Repr()
-	if strings.Index(sizeRepr, "1,2,3,444,5-90") == -1 {
+	if !strings.Contains(sizeRepr, "1,2,3,444,5-90") {
 		t.Errorf("Size filter was expected to have 5 values")
 	}
 }
