@@ -2,7 +2,7 @@ package scraper
 
 import (
 	"fmt"
-	"github.com/ffuf/ffuf/pkg/ffuf"
+	"github.com/ffuf/ffuf/v2/pkg/ffuf"
 	"strings"
 )
 
